import os
from functools import wraps

import rook


def serverless_rook(f):
    on_lambda = 'LAMBDA_TASK_ROOT' in os.environ

    if on_lambda:
        @wraps(f)
        def handler(*args, **kwargs):
            rook.start(log_file="")

            ret = f(*args, **kwargs)

            rook.flush()
            return ret
    else:
        handler = f

    return handler

try:
    from chalice import Chalice

    class RookoutChalice(Chalice):
        @serverless_rook
        def __call__(self, *args, **kwargs):
            return super(RookoutChalice, self).__call__(*args, **kwargs)


except ImportError:
    pass


import collections
import logging
import traceback

from backend.management.log_sender import sender


class JsonHandler(logging.Handler):
    TAGS = "backend"

    def __init__(self):
        super(JsonHandler, self).__init__()

    def close(self):
        pass

    def emit(self, record):
        sender.send(self._build_log(record), self.TAGS)

    def _build_log(self, record):
        data = {
            'name': self.get_name(),
            'msg': record.msg,
            'formatted_message': record.getMessage(),
            'args': record.args,
            'level_name': record.levelname,
            'level_no': record.levelno,
            'path_name': record.pathname,
            'filename': record.filename,
            'module': record.module,
            'lineno': record.lineno,
            'function': record.funcName,
            'time': record.created,
            'thread_id': record.thread,
            'thread_name': record.threadName,
            'process_name': record.processName,
            'process_id': record.process,
            'traceback': traceback.format_exc(),
        }
        if hasattr(record, "rookout_extra"):
            for k, v in record.rookout_extra.items():
                data[k] = v
        return data



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rook.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rook.proto',
  package='',
  syntax='proto3',
  serialized_pb=_b('\n\nrook.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x98\x0e\n\x07Variant\x12#\n\x0cvariant_type\x18\x01 \x01(\x0e\x32\r.Variant.Type\x12\x15\n\roriginal_type\x18\x02 \x01(\t\x12\'\n\nattributes\x18\x03 \x03(\x0b\x32\x13.Variant.NamedValue\x12\x13\n\tint_value\x18\x0b \x01(\x05H\x00\x12\x14\n\nlong_value\x18\x0c \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\r \x01(\x01H\x00\x12\'\n\x0c\x62inary_value\x18\x0e \x01(\x0b\x32\x0f.Variant.BinaryH\x00\x12\'\n\x0cstring_value\x18\x0f \x01(\x0b\x32\x0f.Variant.StringH\x00\x12#\n\nlist_value\x18\x10 \x01(\x0b\x32\r.Variant.ListH\x00\x12!\n\tmap_value\x18\x11 \x01(\x0b\x32\x0c.Variant.MapH\x00\x12-\n\x0fnamespace_value\x18\x13 \x01(\x0b\x32\x12.Variant.NamespaceH\x00\x12\x1d\n\x0b\x65rror_value\x18\x14 \x01(\x0b\x32\x06.ErrorH\x00\x12\x32\n\rmessage_value\x18\x17 \x01(\x0b\x32\x19.Variant.FormattedMessageH\x00\x12\x30\n\ntime_value\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12)\n\ncode_value\x18\x1a \x01(\x0b\x32\x13.Variant.CodeObjectH\x00\x12,\n\x0flarge_int_value\x18\x1b \x01(\x0b\x32\x11.Variant.LargeIntH\x00\x12)\n\rcomplex_value\x18\x1c \x01(\x0b\x32\x10.Variant.ComplexH\x00\x12#\n\nenum_value\x18\x1f \x01(\x0b\x32\r.Variant.EnumH\x00\x1a\x33\n\nNamedValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x05value\x18\x02 \x01(\x0b\x32\x08.Variant\x1a.\n\x06\x42inary\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x0c\x1a.\n\x06String\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\x1a\x45\n\x04List\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x15\n\roriginal_size\x18\x02 \x01(\x05\x12\x18\n\x06values\x18\x03 \x03(\x0b\x32\x08.Variant\x1a\x39\n\x04Pair\x12\x17\n\x05\x66irst\x18\x01 \x01(\x0b\x32\x08.Variant\x12\x18\n\x06second\x18\x02 \x01(\x0b\x32\x08.Variant\x1a:\n\x03Map\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12\x1c\n\x05pairs\x18\x02 \x03(\x0b\x32\r.Variant.Pair\x1a\x34\n\tNamespace\x12\'\n\nattributes\x18\x01 \x03(\x0b\x32\x13.Variant.NamedValue\x1a#\n\x10\x46ormattedMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x1aL\n\nCodeObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06module\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x0e\n\x06lineno\x18\x04 \x01(\r\x1a\x19\n\x08LargeInt\x12\r\n\x05value\x18\x01 \x01(\t\x1a*\n\x07\x43omplex\x12\x0c\n\x04real\x18\x01 \x01(\x01\x12\x11\n\timaginary\x18\x02 \x01(\x01\x1a\x46\n\x04\x45num\x12\x14\n\x0cstring_value\x18\x01 \x01(\t\x12\x15\n\rordinal_value\x18\x02 \x01(\x05\x12\x11\n\ttype_name\x18\x03 \x01(\t\"\xd9\x03\n\x04Type\x12\x10\n\x0cVARIANT_NONE\x10\x00\x12\x0f\n\x0bVARIANT_INT\x10\x01\x12\x10\n\x0cVARIANT_LONG\x10\x02\x12\x12\n\x0eVARIANT_DOUBLE\x10\x03\x12\x12\n\x0eVARIANT_BINARY\x10\x04\x12\x12\n\x0eVARIANT_STRING\x10\x05\x12\x10\n\x0cVARIANT_LIST\x10\x06\x12\x0f\n\x0bVARIANT_MAP\x10\x07\x12\x12\n\x0eVARIANT_OBJECT\x10\x08\x12\x15\n\x11VARIANT_NAMESPACE\x10\t\x12\x11\n\rVARIANT_ERROR\x10\n\x12\x19\n\x15VARIANT_NOT_SUPPORTED\x10\x0b\x12\x15\n\x11VARIANT_MAX_DEPTH\x10\x0c\x12\x1d\n\x19VARIANT_FORMATTED_MESSAGE\x10\r\x12\x10\n\x0cVARIANT_TIME\x10\x0e\x12\x19\n\x15VARIANT_UKNOWN_OBJECT\x10\x0f\x12\x17\n\x13VARIANT_CODE_OBJECT\x10\x10\x12\x15\n\x11VARIANT_LARGE_INT\x10\x11\x12\x13\n\x0fVARIANT_COMPLEX\x10\x12\x12\x15\n\x11VARIANT_UNDEFINED\x10\x13\x12\x13\n\x0fVARIANT_DYNAMIC\x10\x14\x12\x10\n\x0cVARIANT_ENUM\x10\x15\x42\x07\n\x05value\"x\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x1c\n\nparameters\x18\x03 \x01(\x0b\x32\x08.Variant\x12\x15\n\x03\x65xc\x18\x04 \x01(\x0b\x32\x08.Variant\x12\x1b\n\ttraceback\x18\x05 \x01(\x0b\x32\x08.Variant\"\x8e\x04\n\x0fRookInformation\x12\x0f\n\x07rook_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0e\n\x06\x63ommit\x18\x03 \x01(\t\x12\x1b\n\targuments\x18\x05 \x01(\x0b\x32\x08.Variant\x12\x10\n\x08platform\x18\x06 \x01(\t\x12\x15\n\rplatform_type\x18\x07 \x01(\t\x12\x18\n\x10platform_version\x18\x08 \x01(\t\x12\x12\n\nexecutable\x18\t \x01(\t\x12\x19\n\x11\x63ommand_arguments\x18\n \x03(\t\x12\x0c\n\x04tags\x18\x0b \x03(\t\x12\x13\n\x0buser_commit\x18\x0c \x01(\t\x12\x10\n\x08hostname\x18\x15 \x01(\t\x12\x14\n\x0cmachine_type\x18\x16 \x01(\t\x12\x0f\n\x07network\x18\x17 \x01(\t\x12\n\n\x02ip\x18\x18 \x01(\t\x12\n\n\x02os\x18\x19 \x01(\t\x12\x12\n\nos_release\x18\x1a \x01(\t\x12\x12\n\nos_version\x18\x1b \x01(\t\x12\x11\n\tos_string\x18\x1c \x01(\t\x12\x12\n\nprocess_id\x18\x1d \x01(\t\x12\x1a\n\x12user_remote_origin\x18\x1f \x01(\t\x12,\n\x06labels\x18\x1e \x03(\x0b\x32\x1c.RookInformation.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xda\x01\n\x0eRookLogMessage\x12\r\n\x05level\x18\x02 \x01(\r\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x12\n\nclass_name\x18\x05 \x01(\t\x12\x13\n\x0bmethod_name\x18\x06 \x01(\t\x12\x0e\n\x06lineno\x18\x07 \x01(\r\x12\x0c\n\x04text\x18\x08 \x01(\t\x12\x1b\n\targuments\x18\t \x01(\x0b\x32\x08.Variant\x12\x19\n\x11\x66ormatted_message\x18\n \x01(\t\"d\n\x0bUserMessage\x12\x0e\n\x06\x61ug_id\x18\x02 \x01(\t\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\targuments\x18\x04 \x01(\x0b\x32\x08.Variant\":\n\rRpcReturnCode\x12\x12\n\nis_success\x18\x01 \x01(\x08\x12\x15\n\x03\x65xc\x18\x02 \x01(\x0b\x32\x08.Variant\"\x8e\x02\n\x0bRookCommand\x12\'\n\x0c\x63ommand_type\x18\x01 \x01(\x0e\x32\x11.RookCommand.Type\x12\x12\n\x08\x61ug_json\x18\x0b \x01(\tH\x00\x12\x10\n\x06\x61ug_id\x18\x0c \x01(\tH\x00\x12\x11\n\x07rook_id\x18\x0f \x01(\tH\x00\"\x93\x01\n\x04Type\x12\x13\n\x0f\x43OMMAND_MISSING\x10\x00\x12\x13\n\x0f\x43OMMAND_ADD_AUG\x10\x01\x12\x16\n\x12\x43OMMAND_REMOVE_AUG\x10\x02\x12\x18\n\x14\x43OMAND_INIT_FINISHED\x10\x03\x12\x16\n\x12\x43OMMAND_CLEAR_AUGS\x10\x04\x12\x17\n\x13\x43OMMAND_SET_ROOK_ID\x10\x05\x42\x07\n\x05value\"\x1c\n\x0bPingMessage\x12\r\n\x05value\x18\x01 \x01(\x05\"\x85\x01\n\x10RuleStatusUpdate\x12\x0f\n\x07rook_id\x18\x01 \x01(\t\x12\x0f\n\x07rule_id\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\t\x12\x15\n\x05\x65rror\x18\x04 \x01(\x0b\x32\x06.Error\x12(\n\x04time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9b\x01\n\x0cRookMessages\x12\x0f\n\x07rook_id\x18\x01 \x01(\t\x12%\n\x0clog_messages\x18\x02 \x03(\x0b\x32\x0f.RookLogMessage\x12#\n\ruser_messages\x18\x03 \x03(\x0b\x32\x0c.UserMessage\x12.\n\x13rule_status_updates\x18\x04 \x03(\x0b\x32\x11.RuleStatusUpdate2\xe5\x01\n\x16\x41gentManagementService\x12\"\n\x04ping\x12\x0c.PingMessage\x1a\x0c.PingMessage\x12\x39\n\x15new_rook_notification\x12\x10.RookInformation\x1a\x0c.RookCommand0\x01\x12<\n\x17send_rule_status_update\x12\x11.RuleStatusUpdate\x1a\x0e.RpcReturnCode\x12.\n\rsend_messages\x12\r.RookMessages\x1a\x0e.RpcReturnCodeB\x1b\n\x19\x63om.rookout.rook.protobufb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_VARIANT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='Variant.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VARIANT_NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_INT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_LONG', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_DOUBLE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_BINARY', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_STRING', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_LIST', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_MAP', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_OBJECT', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_NAMESPACE', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_ERROR', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_NOT_SUPPORTED', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_MAX_DEPTH', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_FORMATTED_MESSAGE', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_TIME', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_UKNOWN_OBJECT', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_CODE_OBJECT', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_LARGE_INT', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_COMPLEX', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_UNDEFINED', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_DYNAMIC', index=20, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_ENUM', index=21, number=21,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1382,
  serialized_end=1855,
)
_sym_db.RegisterEnumDescriptor(_VARIANT_TYPE)

_ROOKCOMMAND_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='RookCommand.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMMAND_MISSING', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_ADD_AUG', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_REMOVE_AUG', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMAND_INIT_FINISHED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_CLEAR_AUGS', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_SET_ROOK_ID', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3015,
  serialized_end=3162,
)
_sym_db.RegisterEnumDescriptor(_ROOKCOMMAND_TYPE)


_VARIANT_NAMEDVALUE = _descriptor.Descriptor(
  name='NamedValue',
  full_name='Variant.NamedValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Variant.NamedValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='Variant.NamedValue.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=730,
  serialized_end=781,
)

_VARIANT_BINARY = _descriptor.Descriptor(
  name='Binary',
  full_name='Variant.Binary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_size', full_name='Variant.Binary.original_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='Variant.Binary.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=783,
  serialized_end=829,
)

_VARIANT_STRING = _descriptor.Descriptor(
  name='String',
  full_name='Variant.String',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_size', full_name='Variant.String.original_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='Variant.String.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=831,
  serialized_end=877,
)

_VARIANT_LIST = _descriptor.Descriptor(
  name='List',
  full_name='Variant.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='Variant.List.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_size', full_name='Variant.List.original_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='Variant.List.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=879,
  serialized_end=948,
)

_VARIANT_PAIR = _descriptor.Descriptor(
  name='Pair',
  full_name='Variant.Pair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='Variant.Pair.first', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second', full_name='Variant.Pair.second', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=1007,
)

_VARIANT_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='Variant.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_size', full_name='Variant.Map.original_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pairs', full_name='Variant.Map.pairs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1009,
  serialized_end=1067,
)

_VARIANT_NAMESPACE = _descriptor.Descriptor(
  name='Namespace',
  full_name='Variant.Namespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Variant.Namespace.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1069,
  serialized_end=1121,
)

_VARIANT_FORMATTEDMESSAGE = _descriptor.Descriptor(
  name='FormattedMessage',
  full_name='Variant.FormattedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='Variant.FormattedMessage.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1158,
)

_VARIANT_CODEOBJECT = _descriptor.Descriptor(
  name='CodeObject',
  full_name='Variant.CodeObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='Variant.CodeObject.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='module', full_name='Variant.CodeObject.module', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filename', full_name='Variant.CodeObject.filename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lineno', full_name='Variant.CodeObject.lineno', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1160,
  serialized_end=1236,
)

_VARIANT_LARGEINT = _descriptor.Descriptor(
  name='LargeInt',
  full_name='Variant.LargeInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='Variant.LargeInt.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1263,
)

_VARIANT_COMPLEX = _descriptor.Descriptor(
  name='Complex',
  full_name='Variant.Complex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='real', full_name='Variant.Complex.real', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='imaginary', full_name='Variant.Complex.imaginary', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1265,
  serialized_end=1307,
)

_VARIANT_ENUM = _descriptor.Descriptor(
  name='Enum',
  full_name='Variant.Enum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='Variant.Enum.string_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ordinal_value', full_name='Variant.Enum.ordinal_value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type_name', full_name='Variant.Enum.type_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1379,
)

_VARIANT = _descriptor.Descriptor(
  name='Variant',
  full_name='Variant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='variant_type', full_name='Variant.variant_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_type', full_name='Variant.original_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='Variant.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='Variant.int_value', index=3,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='Variant.long_value', index=4,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='Variant.double_value', index=5,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='binary_value', full_name='Variant.binary_value', index=6,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='Variant.string_value', index=7,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='list_value', full_name='Variant.list_value', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_value', full_name='Variant.map_value', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='namespace_value', full_name='Variant.namespace_value', index=10,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_value', full_name='Variant.error_value', index=11,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_value', full_name='Variant.message_value', index=12,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_value', full_name='Variant.time_value', index=13,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code_value', full_name='Variant.code_value', index=14,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='large_int_value', full_name='Variant.large_int_value', index=15,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='complex_value', full_name='Variant.complex_value', index=16,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enum_value', full_name='Variant.enum_value', index=17,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_VARIANT_NAMEDVALUE, _VARIANT_BINARY, _VARIANT_STRING, _VARIANT_LIST, _VARIANT_PAIR, _VARIANT_MAP, _VARIANT_NAMESPACE, _VARIANT_FORMATTEDMESSAGE, _VARIANT_CODEOBJECT, _VARIANT_LARGEINT, _VARIANT_COMPLEX, _VARIANT_ENUM, ],
  enum_types=[
    _VARIANT_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='Variant.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=48,
  serialized_end=1864,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='Error.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='Error.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='Error.parameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exc', full_name='Error.exc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traceback', full_name='Error.traceback', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1866,
  serialized_end=1986,
)


_ROOKINFORMATION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='RookInformation.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='RookInformation.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='RookInformation.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2470,
  serialized_end=2515,
)

_ROOKINFORMATION = _descriptor.Descriptor(
  name='RookInformation',
  full_name='RookInformation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rook_id', full_name='RookInformation.rook_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='version', full_name='RookInformation.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='commit', full_name='RookInformation.commit', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='RookInformation.arguments', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform', full_name='RookInformation.platform', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform_type', full_name='RookInformation.platform_type', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='platform_version', full_name='RookInformation.platform_version', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='executable', full_name='RookInformation.executable', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command_arguments', full_name='RookInformation.command_arguments', index=8,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tags', full_name='RookInformation.tags', index=9,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_commit', full_name='RookInformation.user_commit', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='RookInformation.hostname', index=11,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='machine_type', full_name='RookInformation.machine_type', index=12,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='network', full_name='RookInformation.network', index=13,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip', full_name='RookInformation.ip', index=14,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='os', full_name='RookInformation.os', index=15,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='os_release', full_name='RookInformation.os_release', index=16,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='os_version', full_name='RookInformation.os_version', index=17,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='os_string', full_name='RookInformation.os_string', index=18,
      number=28, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_id', full_name='RookInformation.process_id', index=19,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_remote_origin', full_name='RookInformation.user_remote_origin', index=20,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='labels', full_name='RookInformation.labels', index=21,
      number=30, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_ROOKINFORMATION_LABELSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1989,
  serialized_end=2515,
)


_ROOKLOGMESSAGE = _descriptor.Descriptor(
  name='RookLogMessage',
  full_name='RookLogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='RookLogMessage.level', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='RookLogMessage.time', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filename', full_name='RookLogMessage.filename', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='class_name', full_name='RookLogMessage.class_name', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='RookLogMessage.method_name', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lineno', full_name='RookLogMessage.lineno', index=5,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='RookLogMessage.text', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='RookLogMessage.arguments', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='formatted_message', full_name='RookLogMessage.formatted_message', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2518,
  serialized_end=2736,
)


_USERMESSAGE = _descriptor.Descriptor(
  name='UserMessage',
  full_name='UserMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='aug_id', full_name='UserMessage.aug_id', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='UserMessage.time', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='UserMessage.arguments', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2738,
  serialized_end=2838,
)


_RPCRETURNCODE = _descriptor.Descriptor(
  name='RpcReturnCode',
  full_name='RpcReturnCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_success', full_name='RpcReturnCode.is_success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exc', full_name='RpcReturnCode.exc', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2840,
  serialized_end=2898,
)


_ROOKCOMMAND = _descriptor.Descriptor(
  name='RookCommand',
  full_name='RookCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command_type', full_name='RookCommand.command_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aug_json', full_name='RookCommand.aug_json', index=1,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='aug_id', full_name='RookCommand.aug_id', index=2,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rook_id', full_name='RookCommand.rook_id', index=3,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROOKCOMMAND_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='RookCommand.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2901,
  serialized_end=3171,
)


_PINGMESSAGE = _descriptor.Descriptor(
  name='PingMessage',
  full_name='PingMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='PingMessage.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3173,
  serialized_end=3201,
)


_RULESTATUSUPDATE = _descriptor.Descriptor(
  name='RuleStatusUpdate',
  full_name='RuleStatusUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rook_id', full_name='RuleStatusUpdate.rook_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rule_id', full_name='RuleStatusUpdate.rule_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='active', full_name='RuleStatusUpdate.active', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='RuleStatusUpdate.error', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time', full_name='RuleStatusUpdate.time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3204,
  serialized_end=3337,
)


_ROOKMESSAGES = _descriptor.Descriptor(
  name='RookMessages',
  full_name='RookMessages',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rook_id', full_name='RookMessages.rook_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='log_messages', full_name='RookMessages.log_messages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='user_messages', full_name='RookMessages.user_messages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rule_status_updates', full_name='RookMessages.rule_status_updates', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3340,
  serialized_end=3495,
)

_VARIANT_NAMEDVALUE.fields_by_name['value'].message_type = _VARIANT
_VARIANT_NAMEDVALUE.containing_type = _VARIANT
_VARIANT_BINARY.containing_type = _VARIANT
_VARIANT_STRING.containing_type = _VARIANT
_VARIANT_LIST.fields_by_name['values'].message_type = _VARIANT
_VARIANT_LIST.containing_type = _VARIANT
_VARIANT_PAIR.fields_by_name['first'].message_type = _VARIANT
_VARIANT_PAIR.fields_by_name['second'].message_type = _VARIANT
_VARIANT_PAIR.containing_type = _VARIANT
_VARIANT_MAP.fields_by_name['pairs'].message_type = _VARIANT_PAIR
_VARIANT_MAP.containing_type = _VARIANT
_VARIANT_NAMESPACE.fields_by_name['attributes'].message_type = _VARIANT_NAMEDVALUE
_VARIANT_NAMESPACE.containing_type = _VARIANT
_VARIANT_FORMATTEDMESSAGE.containing_type = _VARIANT
_VARIANT_CODEOBJECT.containing_type = _VARIANT
_VARIANT_LARGEINT.containing_type = _VARIANT
_VARIANT_COMPLEX.containing_type = _VARIANT
_VARIANT_ENUM.containing_type = _VARIANT
_VARIANT.fields_by_name['variant_type'].enum_type = _VARIANT_TYPE
_VARIANT.fields_by_name['attributes'].message_type = _VARIANT_NAMEDVALUE
_VARIANT.fields_by_name['binary_value'].message_type = _VARIANT_BINARY
_VARIANT.fields_by_name['string_value'].message_type = _VARIANT_STRING
_VARIANT.fields_by_name['list_value'].message_type = _VARIANT_LIST
_VARIANT.fields_by_name['map_value'].message_type = _VARIANT_MAP
_VARIANT.fields_by_name['namespace_value'].message_type = _VARIANT_NAMESPACE
_VARIANT.fields_by_name['error_value'].message_type = _ERROR
_VARIANT.fields_by_name['message_value'].message_type = _VARIANT_FORMATTEDMESSAGE
_VARIANT.fields_by_name['time_value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VARIANT.fields_by_name['code_value'].message_type = _VARIANT_CODEOBJECT
_VARIANT.fields_by_name['large_int_value'].message_type = _VARIANT_LARGEINT
_VARIANT.fields_by_name['complex_value'].message_type = _VARIANT_COMPLEX
_VARIANT.fields_by_name['enum_value'].message_type = _VARIANT_ENUM
_VARIANT_TYPE.containing_type = _VARIANT
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['int_value'])
_VARIANT.fields_by_name['int_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['long_value'])
_VARIANT.fields_by_name['long_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['double_value'])
_VARIANT.fields_by_name['double_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['binary_value'])
_VARIANT.fields_by_name['binary_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['string_value'])
_VARIANT.fields_by_name['string_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['list_value'])
_VARIANT.fields_by_name['list_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['map_value'])
_VARIANT.fields_by_name['map_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['namespace_value'])
_VARIANT.fields_by_name['namespace_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['error_value'])
_VARIANT.fields_by_name['error_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['message_value'])
_VARIANT.fields_by_name['message_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['time_value'])
_VARIANT.fields_by_name['time_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['code_value'])
_VARIANT.fields_by_name['code_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['large_int_value'])
_VARIANT.fields_by_name['large_int_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['complex_value'])
_VARIANT.fields_by_name['complex_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['enum_value'])
_VARIANT.fields_by_name['enum_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_ERROR.fields_by_name['parameters'].message_type = _VARIANT
_ERROR.fields_by_name['exc'].message_type = _VARIANT
_ERROR.fields_by_name['traceback'].message_type = _VARIANT
_ROOKINFORMATION_LABELSENTRY.containing_type = _ROOKINFORMATION
_ROOKINFORMATION.fields_by_name['arguments'].message_type = _VARIANT
_ROOKINFORMATION.fields_by_name['labels'].message_type = _ROOKINFORMATION_LABELSENTRY
_ROOKLOGMESSAGE.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROOKLOGMESSAGE.fields_by_name['arguments'].message_type = _VARIANT
_USERMESSAGE.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USERMESSAGE.fields_by_name['arguments'].message_type = _VARIANT
_RPCRETURNCODE.fields_by_name['exc'].message_type = _VARIANT
_ROOKCOMMAND.fields_by_name['command_type'].enum_type = _ROOKCOMMAND_TYPE
_ROOKCOMMAND_TYPE.containing_type = _ROOKCOMMAND
_ROOKCOMMAND.oneofs_by_name['value'].fields.append(
  _ROOKCOMMAND.fields_by_name['aug_json'])
_ROOKCOMMAND.fields_by_name['aug_json'].containing_oneof = _ROOKCOMMAND.oneofs_by_name['value']
_ROOKCOMMAND.oneofs_by_name['value'].fields.append(
  _ROOKCOMMAND.fields_by_name['aug_id'])
_ROOKCOMMAND.fields_by_name['aug_id'].containing_oneof = _ROOKCOMMAND.oneofs_by_name['value']
_ROOKCOMMAND.oneofs_by_name['value'].fields.append(
  _ROOKCOMMAND.fields_by_name['rook_id'])
_ROOKCOMMAND.fields_by_name['rook_id'].containing_oneof = _ROOKCOMMAND.oneofs_by_name['value']
_RULESTATUSUPDATE.fields_by_name['error'].message_type = _ERROR
_RULESTATUSUPDATE.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ROOKMESSAGES.fields_by_name['log_messages'].message_type = _ROOKLOGMESSAGE
_ROOKMESSAGES.fields_by_name['user_messages'].message_type = _USERMESSAGE
_ROOKMESSAGES.fields_by_name['rule_status_updates'].message_type = _RULESTATUSUPDATE
DESCRIPTOR.message_types_by_name['Variant'] = _VARIANT
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['RookInformation'] = _ROOKINFORMATION
DESCRIPTOR.message_types_by_name['RookLogMessage'] = _ROOKLOGMESSAGE
DESCRIPTOR.message_types_by_name['UserMessage'] = _USERMESSAGE
DESCRIPTOR.message_types_by_name['RpcReturnCode'] = _RPCRETURNCODE
DESCRIPTOR.message_types_by_name['RookCommand'] = _ROOKCOMMAND
DESCRIPTOR.message_types_by_name['PingMessage'] = _PINGMESSAGE
DESCRIPTOR.message_types_by_name['RuleStatusUpdate'] = _RULESTATUSUPDATE
DESCRIPTOR.message_types_by_name['RookMessages'] = _ROOKMESSAGES

Variant = _reflection.GeneratedProtocolMessageType('Variant', (_message.Message,), dict(

  NamedValue = _reflection.GeneratedProtocolMessageType('NamedValue', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_NAMEDVALUE,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.NamedValue)
    ))
  ,

  Binary = _reflection.GeneratedProtocolMessageType('Binary', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_BINARY,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.Binary)
    ))
  ,

  String = _reflection.GeneratedProtocolMessageType('String', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_STRING,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.String)
    ))
  ,

  List = _reflection.GeneratedProtocolMessageType('List', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_LIST,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.List)
    ))
  ,

  Pair = _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_PAIR,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.Pair)
    ))
  ,

  Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_MAP,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.Map)
    ))
  ,

  Namespace = _reflection.GeneratedProtocolMessageType('Namespace', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_NAMESPACE,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.Namespace)
    ))
  ,

  FormattedMessage = _reflection.GeneratedProtocolMessageType('FormattedMessage', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_FORMATTEDMESSAGE,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.FormattedMessage)
    ))
  ,

  CodeObject = _reflection.GeneratedProtocolMessageType('CodeObject', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_CODEOBJECT,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.CodeObject)
    ))
  ,

  LargeInt = _reflection.GeneratedProtocolMessageType('LargeInt', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_LARGEINT,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.LargeInt)
    ))
  ,

  Complex = _reflection.GeneratedProtocolMessageType('Complex', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_COMPLEX,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.Complex)
    ))
  ,

  Enum = _reflection.GeneratedProtocolMessageType('Enum', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_ENUM,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:Variant.Enum)
    ))
  ,
  DESCRIPTOR = _VARIANT,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:Variant)
  ))
_sym_db.RegisterMessage(Variant)
_sym_db.RegisterMessage(Variant.NamedValue)
_sym_db.RegisterMessage(Variant.Binary)
_sym_db.RegisterMessage(Variant.String)
_sym_db.RegisterMessage(Variant.List)
_sym_db.RegisterMessage(Variant.Pair)
_sym_db.RegisterMessage(Variant.Map)
_sym_db.RegisterMessage(Variant.Namespace)
_sym_db.RegisterMessage(Variant.FormattedMessage)
_sym_db.RegisterMessage(Variant.CodeObject)
_sym_db.RegisterMessage(Variant.LargeInt)
_sym_db.RegisterMessage(Variant.Complex)
_sym_db.RegisterMessage(Variant.Enum)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:Error)
  ))
_sym_db.RegisterMessage(Error)

RookInformation = _reflection.GeneratedProtocolMessageType('RookInformation', (_message.Message,), dict(

  LabelsEntry = _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), dict(
    DESCRIPTOR = _ROOKINFORMATION_LABELSENTRY,
    __module__ = 'rook_pb2'
    # @@protoc_insertion_point(class_scope:RookInformation.LabelsEntry)
    ))
  ,
  DESCRIPTOR = _ROOKINFORMATION,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:RookInformation)
  ))
_sym_db.RegisterMessage(RookInformation)
_sym_db.RegisterMessage(RookInformation.LabelsEntry)

RookLogMessage = _reflection.GeneratedProtocolMessageType('RookLogMessage', (_message.Message,), dict(
  DESCRIPTOR = _ROOKLOGMESSAGE,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:RookLogMessage)
  ))
_sym_db.RegisterMessage(RookLogMessage)

UserMessage = _reflection.GeneratedProtocolMessageType('UserMessage', (_message.Message,), dict(
  DESCRIPTOR = _USERMESSAGE,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:UserMessage)
  ))
_sym_db.RegisterMessage(UserMessage)

RpcReturnCode = _reflection.GeneratedProtocolMessageType('RpcReturnCode', (_message.Message,), dict(
  DESCRIPTOR = _RPCRETURNCODE,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:RpcReturnCode)
  ))
_sym_db.RegisterMessage(RpcReturnCode)

RookCommand = _reflection.GeneratedProtocolMessageType('RookCommand', (_message.Message,), dict(
  DESCRIPTOR = _ROOKCOMMAND,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:RookCommand)
  ))
_sym_db.RegisterMessage(RookCommand)

PingMessage = _reflection.GeneratedProtocolMessageType('PingMessage', (_message.Message,), dict(
  DESCRIPTOR = _PINGMESSAGE,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:PingMessage)
  ))
_sym_db.RegisterMessage(PingMessage)

RuleStatusUpdate = _reflection.GeneratedProtocolMessageType('RuleStatusUpdate', (_message.Message,), dict(
  DESCRIPTOR = _RULESTATUSUPDATE,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:RuleStatusUpdate)
  ))
_sym_db.RegisterMessage(RuleStatusUpdate)

RookMessages = _reflection.GeneratedProtocolMessageType('RookMessages', (_message.Message,), dict(
  DESCRIPTOR = _ROOKMESSAGES,
  __module__ = 'rook_pb2'
  # @@protoc_insertion_point(class_scope:RookMessages)
  ))
_sym_db.RegisterMessage(RookMessages)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\031com.rookout.rook.protobuf'))
_ROOKINFORMATION_LABELSENTRY.has_options = True
_ROOKINFORMATION_LABELSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
import grpc
from grpc.beta import implementations as beta_implementations
from grpc.beta import interfaces as beta_interfaces
from grpc.framework.common import cardinality
from grpc.framework.interfaces.face import utilities as face_utilities


class AgentManagementServiceStub(object):

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ping = channel.unary_unary(
        '/AgentManagementService/ping',
        request_serializer=PingMessage.SerializeToString,
        response_deserializer=PingMessage.FromString,
        )
    self.new_rook_notification = channel.unary_stream(
        '/AgentManagementService/new_rook_notification',
        request_serializer=RookInformation.SerializeToString,
        response_deserializer=RookCommand.FromString,
        )
    self.send_rule_status_update = channel.unary_unary(
        '/AgentManagementService/send_rule_status_update',
        request_serializer=RuleStatusUpdate.SerializeToString,
        response_deserializer=RpcReturnCode.FromString,
        )
    self.send_messages = channel.unary_unary(
        '/AgentManagementService/send_messages',
        request_serializer=RookMessages.SerializeToString,
        response_deserializer=RpcReturnCode.FromString,
        )


class AgentManagementServiceServicer(object):

  def ping(self, request, context):
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def new_rook_notification(self, request, context):
    """Notify agent of a new Rook waking up. Returns a list of initial augs to add
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def send_rule_status_update(self, request, context):
    """Notify agent of a rule processed successfully (or not..)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def send_messages(self, request, context):
    """Send output messages from Rook to Aug
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AgentManagementServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ping': grpc.unary_unary_rpc_method_handler(
          servicer.ping,
          request_deserializer=PingMessage.FromString,
          response_serializer=PingMessage.SerializeToString,
      ),
      'new_rook_notification': grpc.unary_stream_rpc_method_handler(
          servicer.new_rook_notification,
          request_deserializer=RookInformation.FromString,
          response_serializer=RookCommand.SerializeToString,
      ),
      'send_rule_status_update': grpc.unary_unary_rpc_method_handler(
          servicer.send_rule_status_update,
          request_deserializer=RuleStatusUpdate.FromString,
          response_serializer=RpcReturnCode.SerializeToString,
      ),
      'send_messages': grpc.unary_unary_rpc_method_handler(
          servicer.send_messages,
          request_deserializer=RookMessages.FromString,
          response_serializer=RpcReturnCode.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'AgentManagementService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class BetaAgentManagementServiceServicer(object):
  def ping(self, request, context):
    context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
  def new_rook_notification(self, request, context):
    """Notify agent of a new Rook waking up. Returns a list of initial augs to add
    """
    context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
  def send_rule_status_update(self, request, context):
    """Notify agent of a rule processed successfully (or not..)
    """
    context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)
  def send_messages(self, request, context):
    """Send output messages from Rook to Aug
    """
    context.code(beta_interfaces.StatusCode.UNIMPLEMENTED)


class BetaAgentManagementServiceStub(object):
  def ping(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
    raise NotImplementedError()
  ping.future = None
  def new_rook_notification(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
    """Notify agent of a new Rook waking up. Returns a list of initial augs to add
    """
    raise NotImplementedError()
  def send_rule_status_update(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
    """Notify agent of a rule processed successfully (or not..)
    """
    raise NotImplementedError()
  send_rule_status_update.future = None
  def send_messages(self, request, timeout, metadata=None, with_call=False, protocol_options=None):
    """Send output messages from Rook to Aug
    """
    raise NotImplementedError()
  send_messages.future = None


def beta_create_AgentManagementService_server(servicer, pool=None, pool_size=None, default_timeout=None, maximum_timeout=None):
  request_deserializers = {
    ('AgentManagementService', 'new_rook_notification'): RookInformation.FromString,
    ('AgentManagementService', 'ping'): PingMessage.FromString,
    ('AgentManagementService', 'send_messages'): RookMessages.FromString,
    ('AgentManagementService', 'send_rule_status_update'): RuleStatusUpdate.FromString,
  }
  response_serializers = {
    ('AgentManagementService', 'new_rook_notification'): RookCommand.SerializeToString,
    ('AgentManagementService', 'ping'): PingMessage.SerializeToString,
    ('AgentManagementService', 'send_messages'): RpcReturnCode.SerializeToString,
    ('AgentManagementService', 'send_rule_status_update'): RpcReturnCode.SerializeToString,
  }
  method_implementations = {
    ('AgentManagementService', 'new_rook_notification'): face_utilities.unary_stream_inline(servicer.new_rook_notification),
    ('AgentManagementService', 'ping'): face_utilities.unary_unary_inline(servicer.ping),
    ('AgentManagementService', 'send_messages'): face_utilities.unary_unary_inline(servicer.send_messages),
    ('AgentManagementService', 'send_rule_status_update'): face_utilities.unary_unary_inline(servicer.send_rule_status_update),
  }
  server_options = beta_implementations.server_options(request_deserializers=request_deserializers, response_serializers=response_serializers, thread_pool=pool, thread_pool_size=pool_size, default_timeout=default_timeout, maximum_timeout=maximum_timeout)
  return beta_implementations.server(method_implementations, options=server_options)


def beta_create_AgentManagementService_stub(channel, host=None, metadata_transformer=None, pool=None, pool_size=None):
  request_serializers = {
    ('AgentManagementService', 'new_rook_notification'): RookInformation.SerializeToString,
    ('AgentManagementService', 'ping'): PingMessage.SerializeToString,
    ('AgentManagementService', 'send_messages'): RookMessages.SerializeToString,
    ('AgentManagementService', 'send_rule_status_update'): RuleStatusUpdate.SerializeToString,
  }
  response_deserializers = {
    ('AgentManagementService', 'new_rook_notification'): RookCommand.FromString,
    ('AgentManagementService', 'ping'): PingMessage.FromString,
    ('AgentManagementService', 'send_messages'): RpcReturnCode.FromString,
    ('AgentManagementService', 'send_rule_status_update'): RpcReturnCode.FromString,
  }
  cardinalities = {
    'new_rook_notification': cardinality.Cardinality.UNARY_STREAM,
    'ping': cardinality.Cardinality.UNARY_UNARY,
    'send_messages': cardinality.Cardinality.UNARY_UNARY,
    'send_rule_status_update': cardinality.Cardinality.UNARY_UNARY,
  }
  stub_options = beta_implementations.stub_options(host=host, metadata_transformer=metadata_transformer, request_serializers=request_serializers, response_deserializers=response_deserializers, thread_pool=pool, thread_pool_size=pool_size)
  return beta_implementations.dynamic_stub(channel, 'AgentManagementService', cardinalities, options=stub_options)
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import rook_pb2 as rook__pb2

class AgentManagementServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ping = channel.unary_unary(
        '/AgentManagementService/ping',
        request_serializer=rook__pb2.PingMessage.SerializeToString,
        response_deserializer=rook__pb2.PingMessage.FromString,
        )
    self.new_rook_notification = channel.unary_stream(
        '/AgentManagementService/new_rook_notification',
        request_serializer=rook__pb2.RookInformation.SerializeToString,
        response_deserializer=rook__pb2.RookCommand.FromString,
        )
    self.send_rule_status_update = channel.unary_unary(
        '/AgentManagementService/send_rule_status_update',
        request_serializer=rook__pb2.RuleStatusUpdate.SerializeToString,
        response_deserializer=rook__pb2.RpcReturnCode.FromString,
        )
    self.send_messages = channel.unary_unary(
        '/AgentManagementService/send_messages',
        request_serializer=rook__pb2.RookMessages.SerializeToString,
        response_deserializer=rook__pb2.RpcReturnCode.FromString,
        )


class AgentManagementServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def ping(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def new_rook_notification(self, request, context):
    """Notify agent of a new Rook waking up. Returns a list of initial augs to add
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def send_rule_status_update(self, request, context):
    """Notify agent of a rule processed successfully (or not..)
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def send_messages(self, request, context):
    """Send output messages from Rook to Aug
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AgentManagementServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ping': grpc.unary_unary_rpc_method_handler(
          servicer.ping,
          request_deserializer=rook__pb2.PingMessage.FromString,
          response_serializer=rook__pb2.PingMessage.SerializeToString,
      ),
      'new_rook_notification': grpc.unary_stream_rpc_method_handler(
          servicer.new_rook_notification,
          request_deserializer=rook__pb2.RookInformation.FromString,
          response_serializer=rook__pb2.RookCommand.SerializeToString,
      ),
      'send_rule_status_update': grpc.unary_unary_rpc_method_handler(
          servicer.send_rule_status_update,
          request_deserializer=rook__pb2.RuleStatusUpdate.FromString,
          response_serializer=rook__pb2.RpcReturnCode.SerializeToString,
      ),
      'send_messages': grpc.unary_unary_rpc_method_handler(
          servicer.send_messages,
          request_deserializer=rook__pb2.RookMessages.FromString,
          response_serializer=rook__pb2.RpcReturnCode.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'AgentManagementService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from ..logger import logger

from .error import Error
from ..user_warnings import UserWarnings


class Processor(object):

    def __init__(self, script, factory):
        self._operations = []

        for operation in script:
            self._operations.append(factory.get_operation(operation))

    def process(self, namespace):

        for operation in self._operations:
            try:
                result = operation.execute(namespace)
            except Exception as exc:
                message = "Error in operation"
                logger.exception(message)
                UserWarnings.send_warning(Error(exc=exc, message=message))
                return

            if result is not None:
                return result



import base64

from .namespace import Namespace
from .python_object_namespace import PythonObjectNamespace
from .dumped_primitive_namespace import DumpedPrimitiveNamespace


class StringNamespace(DumpedPrimitiveNamespace):

    def __init__(self, obj, original_size, type, common_type, attributes={}):
        super(StringNamespace, self).__init__(obj, type, common_type, attributes, self.METHODS)
        self.original_size = original_size

    def size(self, args):
        return PythonObjectNamespace(len(self.obj))

    def original_size(self, args):
        return PythonObjectNamespace(self.original_size)

    def to_dict(self):
        return {
            u'@namespace': self.__class__.__name__,
            u'@common_type': self.common_type,
            u'@original_type': self.type,
            u'@original_size' : self.original_size,
            u'@attributes': self.get_attributes_dict(),
            u'@value': self.to_simple_dict(),
            }

    def to_simple_dict(self):
        if self.common_type == 'binary':
            return base64.b64encode(self.obj)
        else:
            return self.obj

    METHODS = (size, original_size)




import six
import re

from ..namespaces.container_namespace import ContainerNamespace

from rook.exceptions import RookAttributeNotFound, RookInvalidBasicPath, RookOperationReadOnly


class BasicPath(object):

    NAME = "basic"

    def __init__(self, configuration):
        if isinstance(configuration, six.string_types):
            string = configuration
        else:
            string = configuration['path']

        self._path_operations = []
        self._last_operation = None

        self._parse_path(string, configuration)

    def read_from(self, root_namespace):
        namespace = root_namespace
        for operation in self._path_operations:
            namespace = operation.read(namespace, False)

        return self._last_operation.read(namespace, False)

    def write_to(self, root_namespace, value):
        namespace = root_namespace
        for operation in self._path_operations:
            namespace = operation.read(namespace, True)

        self._last_operation.write(namespace, value)

    def _parse_path(self, path, configuration):
        matcher = re.compile("[\w[][\w'\"()]*]?")
        raw_operations = matcher.findall(path)
        if not raw_operations:
            raise RookInvalidBasicPath(configuration)

        for operation in raw_operations[:-1]:
            self._path_operations.append(self._build_operation(operation))

        self._last_operation = self._build_operation(raw_operations[-1])

    def _build_operation(self, string):
        if '[' in string:
            value = string.strip('[]')
            return self.LookupOperation(value)
        elif '(' in string:
            function_name, function_arguments = string.strip(')').split('(')
            return self.FunctionOperation(function_name,function_arguments)
        else:
            return self.AttributeOperation(string)

    class AttributeOperation(object):
        def __init__(self, name):
            self.name = name

        def read(self, namespace, create):
            try:
                return namespace.read_attribute(self.name)
            except RookAttributeNotFound as exc:
                if create:
                    namespace.write_attribute(self.name, ContainerNamespace({}))
                    return namespace.read_attribute(self.name)
                else:
                    raise

        def write(self, namespace, value):
            return namespace.write_attribute(self.name, value)

    class LookupOperation:
        def __init__(self, name):
            if name.startswith("'"):
                self.name = name.strip("'")
            elif name.startswith('"'):
                self.name = name.strip('"')
            else:
                self.name = int(name)

        def read(self, namespace, create):
            return namespace.read_key(self.name)

        def write(self, namespace, value):
            raise RookOperationReadOnly(type(self))

    class FunctionOperation:
        def __init__(self, function_name, function_arguments):
            self.function_name = function_name
            self.function_arguments = function_arguments

        def read(self, namespace, create):
            return namespace.call_method(self.function_name, self.function_arguments)

        def write(self, namespace, value):
            raise RookOperationReadOnly(type(self))




from .namespace import Namespace


class FormattedNamespace(Namespace):

    def __init__(self, string):
        super(FormattedNamespace, self).__init__()
        self.obj = string

    def to_dict(self):
        return {
            u'@namespace': self.__class__.__name__,
            u'@common_type': Namespace.__name__,
            u'@value': self.obj,
            }

    def to_simple_dict(self):
        return self.obj



# -*- coding: utf-8 -*-
import os
import sys
import six
from functools import partial

from .exts.cloud_debug_python.module_explorer import GetCodeObjectAtLine, _GetModuleCodeObjects, _GetLineNumbers

from rook.logger import logger

from ..exceptions import RookBdbCodeNotFound, RookBdbSetBreakpointFailed, RookInvalidPositionException

try:
    from . import cdbg_native
    cdbg_native.InitializeModule(None)
except ImportError:
    # Special handling for Google AppEngine (Python 2.7)
    from google.devtools.cdbg.debuglets.python import cdbg_native


class Bdb(object):
    def __init__(self):
        self.fncache = {}
        self._cookies = {}
        self.user_line = None

    def set_trace(self):
        # Not needed
        pass

    def canonic(self, filename):
        if filename[0] == "<" and filename[-1] == ">":
            return filename
        canonic = self.fncache.get(filename)
        if not canonic:
            canonic = os.path.abspath(filename)
            canonic = os.path.normpath(canonic)
            self.fncache[filename] = canonic
        return canonic

    def ignore_current_thread(self):
        # Not needed
        pass

    def set_break(self, module, filename, lineno):
        status, code_object = GetCodeObjectAtLine(module, lineno)
        if not status:
            if hasattr(module, '__file__'):
                logger.debug("CodeNotFound module filename %s", module.__file__)

            for cobj in _GetModuleCodeObjects(module):
                logger.debug("Name: %s", cobj.co_name)
                for cline in _GetLineNumbers(cobj):
                    logger.debug("Name: %s, Line %d", cobj.co_name, cline)

            if code_object == (None, None):
                raise RookBdbCodeNotFound(filename=filename)
            else:
                raise RookInvalidPositionException(filename=filename, line=lineno, alternatives=code_object)

        # Install the breakpoint
        cookie = cdbg_native.SetConditionalBreakpoint(code_object, lineno, None, partial(self._callback, lineno=lineno))
        if not cookie:
            raise RookBdbSetBreakpointFailed()

        self._cookies[filename, lineno] = cookie

    def clear_break(self, filename, lineno):
        pos = filename, lineno
        try:
            cookie = self._cookies[pos]
        except KeyError:
            return

        cdbg_native.ClearConditionalBreakpoint(cookie)
        del self._cookies[pos]

    def clear_all_breaks(self):
        for cookie in six.itervalues(self._cookies):
            cdbg_native.ClearConditionalBreakpoint(cookie)

        self._cookies = {}

    def close(self):
        pass

    def _callback(self, event, frame, lineno):
        if event != cdbg_native.BREAKPOINT_EVENT_HIT:
            logger.error("Unexpected event- %d", event)
            return

        if frame and self.user_line:
            self.user_line(frame, lineno=lineno)



from ..factory import Factory

from .paths.basic_path import BasicPath


class PathsFactory(Factory):

    try:
        STRING_TYPES = (str, unicode)
    except NameError:
        STRING_TYPES = (str, )

    def __init__(self, extended_paths_factories):
        super(PathsFactory, self).__init__()

        self.register_method(BasicPath)

        try:
            from .paths.arithmetic_path import ArithmeticPath
            self.register_method(ArithmeticPath)
        except ImportError:
            pass

        if extended_paths_factories:
            self.register_methods(extended_paths_factories)

    def get_path(self, configuration, factory):
        if isinstance(configuration, self.STRING_TYPES):
            return BasicPath(configuration)
        else:
            return self.get_object(configuration['name'], configuration, factory)



from rook.services.http_server_services.http_server_services import HttpServerService


class HttpServerHandler(object):

    NAME = 'http_server'

    def __init__(self, arguments, processor_factory):
        return

    def add_aug(self, trigger_services, output, aug):
        trigger_services.get_service(HttpServerService.NAME).add_logging_aug(aug)




from .namespace import Namespace


class MaxDepthNamespace(Namespace):

    def to_dict(self):
        return {
            u'@namespace': self.__class__.__name__,
            u'@common_type': Namespace.__name__,
            }

    def to_simple_dict(self):
        return '<MaxDepthLimit>'



from .namespace import Namespace


class DynamicObjectNamespace(Namespace):

    def __init__(self):
        super(DynamicObjectNamespace, self).__init__()

    def to_dict(self):
        return {
            u'@namespace': self.__class__.__name__,
            u'@common_type': "dynamic"
        }

    def to_simple_dict(self):
        return u'<Dynamic>'
